
function extraction_grace_area(lon,lat)

% Extracts loading zone form global GRACE data in grace_global
%
% Note:
% we empirically model and remove secular trends and earthquake-induced
% mass redistribution observable in the gravity field measurements of M>7.5 
% within the 2002-2012 GRACE time span.
%
% Loading data:
% from GRACE, processed by CNRS-GRGS (http://grgs.obs-mip.fr/grace)
%
% Input: - lat: latitude vector of loading zone 
%        - lon: longitude vector of loading zone 
% (note that the GRACE loading grid has a 1x1 degree spacing)
%
% Output: - grace_extract folder with equivalent water heigt files for 
%           loading zone / date
%
% Calls: none
% Called by: main.m
%
% K. Chanard, last modified 20-03-14, from M. Barr 31-07-14


nlat = length(lat); nlon = length(lon);
lon1 = lon(1); lon2 = lon(nlon);
lat1 = lat(1); lat2 = lat(nlat);

grace_directory_g = dir(fullfile('./grace_global/20*')); 
grace_global = {grace_directory_g.name}';
ngrace_g = length(grace_global);

if ~exist('grace_extract', 'dir')
  mkdir('grace_extract');
end

    for j=1 : ngrace_g;                              % Analysis of each GRACE data
        disp(sprintf('Extracting zone lon=[%3.1f,%3.1f], lat=[%3.1f,%3.1f] from GRACE file # %d out of 365',lon1,lon2,lat1,lat2,j)) 
        name_j = grace_global{j};                    % Conserve current file's name
        
        gracej = fullfile('./grace_global',grace_global{j});
        [lon_m,lat_m,loads_m] = textread(gracej,'%f%f%f');
        
        ind1 = find(lat_m <= lat2 & lat_m >= lat1);  % Keep only latitudes belonging to the study area
        ind2 = find(lon_m <= lon2 & lon_m >= lon1);  % Keep only longitudes belonging to the study area
        
        ind = intersect(ind1, ind2);                 % Junction of the 2 conditions
        grace_j = zeros(length(ind),3);

            for i = 1 : length(ind);
                grace_j(i,:) = [lon_m(ind(i)),lat_m(ind(i)),loads_m(ind(i))];
                                                     % Creation of a new GRACE data containing informations of
                                                     % points of the study area only
            end
        
        cd ./grace_extract
       
        dlmwrite([num2str(name_j)], grace_j,'delimiter','\t','precision',9);
                                                     % All theses GRACE data files keep the same name and are stocked
                                                     % in the 'grace_extract'file
        cd ../
    
    end   

end


