function main(lon,lat,cgps_location)

% Compute surface displacementsinduced by seasonal variations of 
% continental water, non-tidal and atmospherical surface loading
%
% Loading data:
% from GRACE, processed by CNRS-GRGS (http://grgs.obs-mip.fr/grace)
%
% Input: - lat: latitude vector of loading zone 
%        - lon: longitude vector of loading zone 
% (note that the GRACE loading grid has a 1x1 degree spacing)
%        - 'cgps_location': text file in between quotes with 
%                         station_name/longitude/latitude where you wish to
%                         compute displacements induced by surface loads
%
% Output: - grace_extract folder with equivalent water heigt files for 
%           loading zone / date
%          - green_functions_horizontal.mat
%          - green_functions_vertical.mat
%          - disp_zone folder with .mat files of east,north and
%            vertical displacements for all points in loading zone, by
%            date
%          - disp_gps folder with ascii files of t/east/north/vertical
%            displacements at each location referenced in 'cgps_location' 
%            file            
%
% Calls: - extraction_grace_area.m to extract loading zone from GRACE data
%        - model_seasonal_var.m to compute displacements induced by surface
%          loads in the loading zone and at locations referenced in 
%          'cgps_location' file
%
% Called by: none
%
% Associated plotting functions:
%        - plot_disp_ts.m: displacement time series at gps stations
%        - plot_grace_ts.m: equivalent water height (EWH) time series 
%        derived from GRACE
%        - plot_tmaps.m: maps of EWH, East/North/Vertical displacements in
%          extracted loading zone / time
%
% K. Chanard, last modified 20-03-14, from M. Barr 31-07-14
                                 


%%                    ******* Load GRACE data *******  

% Create 'grace_extract' folder containing loading files in the zone of 
% interest, from GRACE global dataset

extraction_grace_area(lon,lat);

% Note to change input loading data   
% If you wish to use another loading dataset, create your own lon/lat/h
% files by date in a grace_extract folder and modify calendar.txt 

%%                  ******* Compute displacements *******  

model_seasonal_var(lon,lat,cgps_location);

end