function plot_disp_ts

% Plots East/North/Vertical displacement time series at (y)
% all locations specified in 'cgps_location' file or (n) at specific
% location using station name
%
% Input: none
%
% Output: - (y) disp_gps/figures folder with .eps figures of displacement time
%           series at all locations in 'cgps_location' file
%          - (n) disp_gps/figures foler with .eps figures of displacement time
%            series at specific location using station name
   
% Loads: disp_gps/displacements_cgps, from model_seasonal_var.m 
% 
% Calls: none
% Called by: none
%
% K. Chanard, last modified 20-03-14


load disp_gps/displacements_cgps
prompt1 = 'Plot and save all time series? y/n :  ';
str1 = input(prompt1,'s');

if ~exist('disp_gps/figures', 'dir')
  mkdir('disp_gps/figures');
end

if str1=='y'
    
    figure(1);
    
    for i=1:ngps
        
        subplot(3,1,1); plot(time,ee(:,i),'r','LineWidth',2);  % East 
        title(rname{i}, 'FontSize',14); xlabel('Year'); ylabel('East (mm)');
        xlim([2002.6 2012.6])
        subplot(3,1,2); plot(time,nn(:,i),'r','LineWidth',2);  % North
        xlabel('Year'); ylabel('North (mm)');
        xlim([2002.6 2012.6])
        subplot(3,1,3); plot(time,uu(:,i),'r','LineWidth',2);  % Vertical
        xlabel('Year'); ylabel('Vertical (mm)');
        xlim([2002.6 2012.6])
        
        filename=sprintf('disp_gps/figures/%s',rname{i});
        print('-depsc2','-painters', filename)
        clf;
    end
    
else
    prompt2 = 'Plot and save single time series - Enter name of station ';
    str2 = input(prompt2,'s');
    tmp=strcmp(str2,rname);
    [ind,~]=find(tmp==1); 
    if isempty(ind)==1
        disp('non-existing station')
    else
    figure(1);
    subplot(3,1,1); plot(time,ee(:,ind),'r','LineWidth',2);  % East 
    title(rname{ind}, 'FontSize',14);
    xlabel('Year','FontSize',12); ylabel('East (mm)','FontSize',12);
    xlim([2002.6 2012.6])
    subplot(3,1,2); plot(time,nn(:,ind),'r','LineWidth',2);  % North
    xlabel('Year','FontSize',12); ylabel('North (mm)','FontSize',12);
    xlim([2002.6 2012.6])
    subplot(3,1,3); plot(time,uu(:,ind),'r','LineWidth',2);  % Vertical
    xlabel('Year','FontSize',12); ylabel('Vertical (mm)','FontSize',12);
    xlim([2002.6 2012.6])
    filename=sprintf('disp_gps/figures/%s',rname{ind});
    print('-depsc2','-painters', filename)
    end
end
    
end
