function plot_grace_ts(flon,flat)

% Plots Equivalent Water Height (EWH) time series derived from GRACE at a
% specific lon/lat points given as inputs 
%
% Input: - lon, lat: vectors of longitude and latitudes of points where 
%          you wish to plot EWH
%
% Output: - disp_zone/figures folder with .eps figures of EWH at each point
%           of lon/lat vectors
%   
% Loads: grace_exctract/grace_ts, from model_seasonal_var.m 
% 
% Calls: none
% Called by: none
%
% K. Chanard, last modified 20-03-14


    if ~exist('grace_extract/figures', 'dir')
        mkdir('grace_extract/figures');
    end
    
    load grace_extract/grace_ts

    for i=1:length(flat)
        
        ind = find(flon(i)==iclon & flat(i)==iclat); 
        
        figure(1);
        plot(time,tloads(:,ind),'r','LineWidth',2);
        tname=sprintf('Point lat=%3.1f, lon=%3.1f',flat(i),flon(i));
        title(tname,'FontSize',14); xlabel('Year','FontSize',14); ylabel('Equivalent Water Height (mm)','FontSize',14);
        xlim([2002.6 2012.6])    

        filename=sprintf('grace_extract/figures/Point_lat_%3.1f_lon_%3.1f',flat(i),flon(i));
        print('-depsc2','-painters', filename);
       clf;
    end
    
end
