function plot_tmaps(lon,lat,fdate)

% Plots GRACE loading map and East/North/Vertical displacement maps for
% extracted (lon,lat) zone at specfic date (fdate)
%
% Input: - lat: latitude vector of loading zone 
%        - lon: longitude vector of loading zone 
%        - fdate (one of the grace files names, ex: '2002_08_08_2002_08_17')
%
% Output: -  disp_zone/figures folder with .eps maps of GRACE loading and 
%            East/North/Vertical displacements at time fdate
%
% Loads: - disp_zone/FDATE_de-dn-du.mat files, from model_seasonal_var.m 
%        - grace_extract/FDATE load file     
%
% Calls: none
% Called by: none
%
% K. Chanard, last modified 20-03-14

if ~exist('disp_zone/figures', 'dir')
  mkdir('disp_zone/figures');
end

feast=sprintf('disp_zone/%s_de.mat',fdate);load(feast);
fnorth=sprintf('disp_zone/%s_dn.mat',fdate);load(fnorth);
fvertical=sprintf('disp_zone/%s_du.mat',fdate);load(fvertical);

floads=sprintf('grace_extract/%s',fdate);
[~,~,ewh]=textread(floads,'%f%f%f');

nlat = length(lat); nlon = length(lon);
mloads = zeros(nlat,nlon);      

for i=1:nlat; 
   for j=1:nlon;
        mloads(i,j) = ewh((nlon*nlat)+j-(i*nlon)); 
   end
end
        
[olon,olat] = meshgrid(lon,lat);  
figure(1);
subplot(2,2,1); contourf(olon,olat,mloads);colorbar;
xlabel('Longitude','FontSize',14);ylabel('Latitude','FontSize',14);
title('EWH from GRACE (mm)','FontSize',14);
subplot(2,2,2); contourf(olon,olat,tmpe);colorbar;
xlabel('Longitude','FontSize',14);ylabel('Latitude','FontSize',14);
title('East disp. (mm)','FontSize',14);
subplot(2,2,3); contourf(olon,olat,tmpn);colorbar;
xlabel('Longitude','FontSize',14);ylabel('Latitude','FontSize',14);
title('North disp.(mm)','FontSize',14)
subplot(2,2,4); contourf(olon,olat,tmpu);colorbar;
xlabel('Longitude','FontSize',14);ylabel('Latitude','FontSize',14);
title('Vertical disp. (mm)','FontSize',14);  

filename=sprintf('disp_zone/figures/%s',fdate);
print('-depsc2','-painters', filename)

end